import os
from setuptools import setup, find_packages

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

# Get all of the bin/ etc/ lib/ src/ test/ files for use as package data
def recursive_walk(startdir):
    file_list = []
    for dirname, subdirList, fileList in os.walk(startdir, followlinks=True):
	for fname in fileList:
            file_list.append(os.path.join(dirname, fname))
        for sdname in subdirList:
            sdfiles = recursive_walk(sdname)
            file_list.extend(sdfiles)
    return file_list

pkg_data_files = ['netMHC']
os.chdir('netmhc_3_4_executable')
for subdir in ['bin', 'etc', 'lib', 'src', 'test']:
    file_list = recursive_walk(subdir)
    pkg_data_files.extend(file_list)
os.chdir(os.pardir)

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

setup(
    name="netmhc-3.4-executable",
    version="0.6",
    packages=['netmhc_3_4_executable' ],
    package_data={ 'netmhc_3_4_executable': pkg_data_files },
    description='Python package to provide netMHC executable',
    long_description=README,
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 2',
    ]
)
